@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::pm_groups;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.016';
+our $VERSION = '1.017';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -38,6 +38,12 @@ Philippe Bruhat (BooK)
 
 =item *
 
+2013-12-09 - v1.017
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.038.
+
+=item *
+
 2013-10-14 - v1.016
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.037.
@@ -244,6 +250,7 @@ Albany_pm
 Albuquerque_pm
 AnnArbor_pm
 Atlanta_pm
+Austin_pm
 Baltimore_pm
 Boston_pm
 Boulder_pm
