@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::wales_towns;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -43,6 +43,12 @@ Abigail, Philippe Bruhat (BooK).
 
 =item *
 
+2013-12-09 - v1.004
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.038.
+
+=item *
+
 2013-10-14 - v1.003
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.037.
@@ -114,7 +120,6 @@ Blaina
 Brecon
 Bridgend
 Briton_Ferry
-Brittania
 Brynmawr
 Buckley
 Builth_Wells
